/***
SUPPLEMENTARY MATERIAL 1 to the paper 
"Convergence behavior of optimal cut-off points derived from receiver operating characteristics curve analysis: a simulation study", Mathematics (MDPI)
Oct 5, 2022
***/
/*** *** *** **** STRUCTURE OF DO FILE *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** ***
---lines 20-88: density curve plots; Fig. 1
---lines 95-207: empirically determined ROC curves and true optimal cut-off points for Scenario 1-4; Appendix Fig.A1, Table 1
---lines 210-448: definition of macros
---lines 460-564: generalization of result data sets 
---lines 568-601: visualization of chosen cut-off points by sample size for Scenario 1; Fig. 2
---lines 610-654: line plots of chosen cut-off points for the first nine trials of Scenario 1; Fig. 3
---lines 660-682: bias and mean squared error (MSE) of cut-off points in fixed sample designs; Table 2
---lines 685-707: bias, MSE, mean number of patients (95% CI) of heuristic algorithm I; Table 3
---lines 710-732: bias, MSE, mean number of patients (95% CI) of heuristic algorithm II; Table 4
---lines 735-831: equivalent figures for Scenarios 2-4 for Fig. 2; Suppl. Mat. S3;
---lines 834-894: real-life example (Section 4); Appendix Fig. A2 and Fig. 4
---line 896: END-OF-FILE
***  *** *** *** *** *** *** *** *** *** ***  *** *** *** *** *** *** *** *** *** *** *** *** *** *** ***/

cd "C:\temp"
/***************************/
/*** density curve plots ***/
/***************************/
clear
***;
*#1;
***;
twoway function y = normalden(x,2,1), range(-1 7) || function y = normalden(x,4,1), range(-1 7) legend(off) ylabel(0(.05).4, angle(0)) xlabel(-1(1)7) ytitle("Density") xline(3, lpattern(shortdash)) xline(3, lpattern(dot))
graph save "Graph" "fig1a.gph", replace

*FP;
di 1-normal((3-2)/1)
*FN;
di normal((3-4)/1)


****;
*#2b;
****;
twoway function y = normalden(x,2,1), range(-1 10) || function y = normalden(x,5,2), range(-1 10) legend(off) ylabel(0(.05).4, angle(0)) xlabel(-1(1)10) ytitle("Density") xline(3.41, lpattern(shortdash)) xline(3.18, lpattern(dot))
graph save "Graph" "fig1b.gph", replace

*FP;
di 1-normal((3.41-2)/1)
*FN;
di normal((3.41-5)/2)


***;
*#3;
***;
twoway function y = normalden(x,2,1), range(-1 15) || function y = gammaden(2,2,3,x), range(-1 15) legend(off) ylabel(0(.05).4, angle(0)) xlabel(-1(1)15) ytitle("Density") xline(3.6, lpattern(shortdash)) xline(3.65, lpattern(dot))
*note: gammaden(a,b,g,x) [fx.pdf];
*note: 'visually optimal' nearest cutoff: 3.65;
graph save "Graph" "fig1c.gph", replace


*FP;
di 1-normal((3.6-2)/1)
*FN;
di gammap(2,.3)
*note: Probabilities for the three-parameter gamma distribution (see gammaden()) can be calculated by shifting and scaling x; that is, gammap(a,(x-g)/b).[STATA: fn.pdf];
di (3.6-3)/2


***;
*#4;
***;
twoway function y = exponentialden(2,x), range(0 15) || function y = gammaden(2,2,3,x), range(0 15) legend(off) ylabel(0(.05).5, angle(0)) xlabel(0(1)15) ytitle("Density") xline(3.44, lpattern(shortdash)) xline(3.88, lpattern(dot))
graph save "Graph" "fig1d.gph", replace

*FP;
di 1-exponential(2,3.44)
*FN;
di gammap(2,.22)
*note: Probabilities for the three-parameter gamma distribution (see gammaden()) can be calculated by shifting and scaling x; that is, gammap(a,(x-g)/b).[STATA: fn.pdf];
di (3.44-3)/2
*note: empirical 'optimal' nearest cutoff: 3.88;


/*************************/
/***** FIGURE 1 **********/
/*************************/
graph combine "fig1a.gph" "fig1b.gph" "fig1c.gph" "fig1d.gph", row(2)
graph save "Graph" "fig1.gph", replace
graph export "fig1.tif", as(tif) name("Graph") width(1200) replace
graph export "fig1.png", as(png) name("Graph") replace






/*********************************************************************/
/* empirical optimal cut-off points and ROC curves for scenarios 1-4 */
/*     (sample size: N=10,000,000, prevalence=0.5)                   */
/*********************************************************************/
clear
set seed 20220421
set obs 10000000
gen id = _n
gen group = cond(id<=5000000, 0, 1)


*Scenario 1;
gen scen1 = cond(id<=5000000, rnormal(2,1), rnormal(4,1))
roctab group scen1, graph
graph save "Graph" "figrocscen1.gph", replace

cutpt group scen1, nearest
*3;
cutpt group scen1, liu
*3;
cutpt group scen1, youden
*3;


*Scenario 3;
gen scen3 = cond(id<=5000000, rnormal(2,1), rgamma(2,2)+3)
roctab group scen3, graph
graph save "Graph" "figrocscen3.gph", replace

cutpt group scen3, nearest
*3.65;
cutpt group scen3, liu
*3.6;
cutpt group scen3, youden
*3.6;


*Scenario 4;
gen scen4 = cond(id<=5000000, rexponential(2), rgamma(2,2)+3)
roctab group scen4, graph
graph save "Graph" "figrocscen4.gph", replace

cutpt group scen4, nearest
*3.88;
cutpt group scen4, liu
*3.53;
cutpt group scen4, youden
*3.44;


*Scenario 2;
set seed 20220629
gen scen2b = cond(id<=5000000, rnormal(2,1), rnormal(5,2))
roctab group scen2b, graph
graph save "Graph" "figrocscen2.gph", replace

cutpt group scen2b, nearest
*3.18;
cutpt group scen2b, liu
*3.34;
cutpt group scen2b, youden
*3.41;


/******************************/
/*** Appendix FIGURE A1 *******/ 
/***** ROC curves *************/
/******************************/
graph combine "figrocscen1.gph" "figrocscen2.gph" "figrocscen3.gph" "figrocscen4.gph", row(2)
graph save "Graph" "figroccurves.gph", replace
graph export "figroccurves.tif", as(tif) name("Graph") width(1200) replace
graph export "figroccurves.png", as(png) name("Graph") replace


*true cut-off point determination for scenarios 1-4; 
clear
set obs 6000
gen x = _n /1000

*scenario 1;
gen sens1 = 1-normal((x-4)/1)
gen spec1 = normal((x-2)/1)

*scenario 2;
gen sens2 = 1-normal((x-5)/2)
gen spec2 = normal((x-2)/1)

*scenario 3;
gen sens3 = 1-gammap(2,(x-3)/2)
gen spec3 = normal((x-2)/1)

*scenario 4;
gen sens4 = 1-gammap(2,(x-3)/2)
gen spec4 = exponential(2,x)


forvalues l = 1(1)4 {
gen closest= sqrt((1-sens`l')^2+(1-spec`l')^2)
genera liu = sens`l'*spec`l'
gen youden = sens`l' + spec`l' - 1

sort closest
generate closest_ind = _n == 1

sort liu
generate liu_ind = _n == _N

sort youden
generate youden_ind = _n == _N

li x closest_ind youden_ind liu_ind if closest_ind == 1 | youden_ind == 1 | liu_ind == 1
drop closest* youden* liu*
}


/*****************************************************************************/
/****************** MACROS ***************************************************/
/*****************************************************************************/
capture program drop _all 
clear

global pts 801
global pts2 1401
global trials 1000

set obs $trials
gen trial = _n
save "trialmock.dta", replace

clear
set obs $pts
gen patid = _n
cross using "trialmock.dta"
order trial patid
sort trial patid
save "data_setup.dta", replace

clear
set obs $pts2
gen patid = _n
cross using "trialmock.dta"
order trial patid
sort trial patid
save "data_setup2.dta", replace
erase "trialmock.dta"


program define scenario1
args prevalence seedno

use data_setup.dta, clear
gen prev = `prevalence'
set seed `seedno'
gen randuni = runiform()
gen status = cond(randuni<prev, 1, 0)
tab status
gen marker = cond(randuni<prev, rnormal(4,1), rnormal(2,1))

*FP;
di 1-normal((3-2)/1)
*FN;
di normal((3-4)/1)

twoway (hist marker if status==0) (hist marker if status==1), xlabel(-3(1)9) 

cutpt status marker, nearest
end



program define scenario2
args prevalence seedno

use data_setup.dta, clear
gen prev = `prevalence'
set seed `seedno'
gen randuni = runiform()
gen status = cond(randuni<prev, 1, 0)
tab status
gen marker = cond(randuni<prev, rnormal(5,2), rnormal(2,1))

*FP;
di 1-normal((3.41-2)/1)
*FN;
di normal((3.41-5)/2)

twoway (hist marker if status==0) (hist marker if status==1), xlabel(-3(1)10) 

cutpt status marker, nearest
end


program define scenario3
args prevalence seedno

use data_setup.dta, clear
gen prev = `prevalence'
set seed `seedno'
gen randuni = runiform()
gen status = cond(randuni<prev, 1, 0)
tab status
gen marker = cond(randuni<prev, 3+rgamma(2,2), rnormal(2,1))

*FP;
di 1-normal((3.6-2)/1)
*FN;
di gammap(2,0.3)

twoway (hist marker if status==0) (hist marker if status==1), xlabel(-5(2.5)35) 

cutpt status marker, nearest
end
*note: https://www.stata.com/statalist/archive/2011-06/msg00615.html;


program define scenario4
args prevalence seedno

use data_setup.dta, clear
gen prev = `prevalence'
set seed `seedno'
gen randuni = runiform()
gen status = cond(randuni<prev, 1, 0)
tab status
gen marker = cond(randuni<prev, 3+rgamma(2,2), rexponential(2))

*FP;
di 1-exponential(2,3.45)
*FN;
di gammap(2,.225)

twoway (hist marker if status==0) (hist marker if status==1), xlabel(0(2.5)35)

cutpt status marker, nearest
end
*note: https://www.stata.com/statalist/archive/2011-06/msg00615.html;


/* All scenarios: evaluation of 101, 151, 201, ..., 801 patients */
program define evaluation
tempname sim
postfile `sim' trial patients cutpoint using results.dta, replace
quietly {
forvalues j = 1(1)$trials {
  forvalues i = 101(50)$pts {
	cutpt status marker if patid<=`i' & trial==`j', nearest
    scalar optco=e(cutpoint)
    post `sim' (`j') (`i') (optco) 
}
}
}
postclose `sim'
end




/* Scenario 1: evaluation of N=851, 901, 951, ..., 1201 patients */
program define evaluation851
tempname sim
postfile `sim' trial patients cutpoint using results.dta, replace
quietly {
forvalues j = 1(1)$trials {
  forvalues i = 851(50)$pts2 {
	cutpt status marker if patid<=`i' & trial==`j', nearest
    scalar optco=e(cutpoint)
    post `sim' (`j') (`i') (optco) 
}
}
}
postclose `sim'
end




/* bias and MSE for fixed sample sizes */
program define cutofffixedsamples
args scenario prevalence truth

use results_scen`scenario'_prev`prevalence'.dta, clear

*absolute deviation and squared error;
gen abserr = cutpoint-`truth'
gen biasproc = (cutpoint-`truth')/`truth'*100
gen squerr = (cutpoint-`truth')^2

*bias and MSE;
tabstat abserr biasproc squerr, statistics(N mean) by(patients)
end


/* heuristically evaluating an optimal cut-off point, with steps of n=50 */
program define optcutoff
args scenario prevalence truth

use results_scen`scenario'_prev`prevalence'.dta, clear
*relative changes (in %);
gen change_co = (cutpoint - cutpoint[_n-1]) / cutpoint[_n-1]
replace change_co = . if patients==101

*indicate rel. changes smaller than 1%;
gen ind1proc = cond(abs(change_co)<=0.01, 1, 0)
drop if ind1proc==0
by trial, sort: generate firstrepeat = _n == 1
drop if firstrepeat==0
drop ind1proc firstrepeat
tab patients 
sum patients

*absolute deviation and squared error;
gen abserr = cutpoint-`truth'
gen biasproc = (cutpoint-`truth')/`truth'*100
gen squerr = (cutpoint-`truth')^2

*bias and MSE;
tabstat abserr biasproc squerr, statistics(N mean) 

*95% CI for proposed optimal cut point and mean no. of patients;
ci mean cutpoint patients
end


/* heuristically evaluating an optimal cut-off point, with steps of n=100 */
program define optcutoff2
args scenario prevalence truth

use results_scen`scenario'_prev`prevalence'.dta, clear
*delete results for N=151, 251, 351, ..., 751;
drop if inlist(patients,151,251,351,451,551,651,751)
*relative changes (in %);
gen change_co = (cutpoint - cutpoint[_n-1]) / cutpoint[_n-1]
replace change_co = . if patients==101

*indicate rel. changes smaller than 1%;
gen ind1proc = cond(abs(change_co)<=0.01, 1, 0)
drop if ind1proc==0
by trial, sort: generate firstrepeat = _n == 1
drop if firstrepeat==0
drop ind1proc firstrepeat
tab patients 
sum patients

*absolute deviation and squared error;
gen abserr = cutpoint-`truth'
gen biasproc = (cutpoint-`truth')/`truth'*100
gen squerr = (cutpoint-`truth')^2

*bias and MSE;
tabstat abserr biasproc squerr, statistics(N mean) 

*95% CI for proposed optimal cut point and mean no. of patients;
ci mean cutpoint patients
end











/*****************************************************************************/
/******************** EVALUATION *********************************************/
/*****************************************************************************/

****************
***Scenario 1***
****************
*prevalence=0.1;
scenario1 0.1 20220112
evaluation
copy results.dta "results_scen1_prev01.dta", replace

*prevalence=0.3;
scenario1 0.3 20220114
evaluation
copy results.dta "results_scen1_prev03.dta", replace

*prevalence=0.5;
scenario1 0.5 20220112
evaluation
copy results.dta "results_scen1_prev05.dta", replace

*prevalence=0.5, N=851(50)1,401 [note: increased sample size for Figure 3];
scenario1 0.5 20220112
evaluation851
copy results.dta "results_scen1_851_prev05.dta", replace

*prevalence=0.7;
scenario1 0.7 20220114
evaluation
copy results.dta "results_scen1_prev07.dta", replace


******************
*** Scenario 2 ***
******************
*prevalence=0.1;
scenario2 0.1 20220629
evaluation
copy results.dta "results_scen2_prev01.dta", replace

*prevalence=0.3;
scenario2 0.3 24051938
evaluation
copy results.dta "results_scen2_prev03.dta", replace

*prevalence=0.5;
scenario2 0.5 19480712
evaluation
copy results.dta "results_scen2_prev05.dta", replace

*prevalence=0.7;
scenario2 0.7 19380315
evaluation
copy results.dta "results_scen2_prev07.dta", replace



******************
*** Scenario 3 ***
******************
*prevalence=0.1;
scenario3 0.1 19380315
evaluation
copy results.dta "results_scen3_prev01.dta", replace

*prevalence=0.3;
scenario3 0.3 19500630
evaluation
copy results.dta "results_scen3_prev03.dta", replace

*prevalence=0.5;
scenario3 0.5 20220120
evaluation
copy results.dta "results_scen3_prev05.dta", replace

*prevalence=0.7;
scenario3 0.7 19480712
evaluation
copy results.dta "results_scen3_prev07.dta", replace



******************
*** Scenario 4 ***
******************
*prevalence=0.1;
scenario4 0.1 19240715
evaluation
copy results.dta "results_scen4_prev01.dta", replace

*prevalence=0.3;
scenario4 0.3 19460306
evaluation
copy results.dta "results_scen4_prev03.dta", replace

*prevalence=0.5;
scenario4 0.5 20220120
evaluation
copy results.dta "results_scen4_prev05.dta", replace

*prevalence=0.7;
scenario4 0.7 19380524
evaluation
copy results.dta "results_scen4_prev07.dta", replace



*limits of 1% deviation from true optimal cut-off point in Scenario 1;
di 3*.99
di 3*1.01

use results_scen1_prev01.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2(.5)4.6, angle(0)) yline(2.97 3.03) yticks(2.25(.5)4.25) 
graph save "Graph" "fig2a.gph", replace

use results_scen1_prev03.dta, clear
label var cutpoint "Cut-off point"
*graph box cutpoint, over(patients) ylabel(2.2(.2)3.6, angle(0)) yline(2.97 3.03)
graph hbox cutpoint, over(patients) ylabel(2(.5)4.6, angle(0)) yline(2.97 3.03) yticks(2.25(.5)4.25) 
graph save "Graph" "fig2b.gph", replace

use results_scen1_prev05.dta, clear
label var cutpoint "Cut-off point"
*graph box cutpoint, over(patients) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03)
graph hbox cutpoint, over(patients) ylabel(2(.5)4.6, angle(0)) yline(2.97 3.03) yticks(2.25(.5)4.25) 
graph save "Graph" "fig2c.gph", replace

use results_scen1_prev07.dta, clear
label var cutpoint "Cut-off point"
*graph box cutpoint, over(patients) ylabel(2.2(.2)3.6, angle(0)) yline(2.97 3.03)
graph hbox cutpoint, over(patients) ylabel(2(.5)4.6, angle(0)) yline(2.97 3.03) yticks(2.25(.5)4.25) 
graph save "Graph" "fig2d.gph", replace

/*************************/
/***** FIGURE 2 **********/
/*************************/
graph combine "fig2a.gph" "fig2b.gph" "fig2c.gph" "fig2d.gph", row(2)
graph save "Graph" "fig2.gph", replace
graph export "fig2.tif", as(tif) name("Graph") width(1200) replace
graph export "fig2.png", as(png) name("Graph") replace








/****************************************************************/
/** check: optimal cut-off points for trials 1-9 in Scenario 1 **/
/****************************************************************/
*args: scenario prevalence truth;
optcutoff 1 05 3
li trial patients cutpoint if trial<10

optcutoff2 1 05 3
li trial patients cutpoint if trial<10

/*****************************************/
/*single-study examples: Scen 1 (n=1,401)*/
/*****************************************/
use results_scen1_prev05.dta, clear
append using results_scen1_851_prev05.dta
label var cutpoint "Cut-off point"
label var patients "Patients"
tab patients
save results_scen1_all_prev05.dta, replace

twoway line cutpoint patients if trial==1, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(151, lpattern(dot)) xline(201, lpattern(shortdash_dot)) xlabel(201(300)1401) 
graph save "Graph" "fig3a.gph", replace
twoway line cutpoint patients if trial==2, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(351, lpattern(dot)) xline(501, lpattern(shortdash_dot)) xlabel(201(300)1401)
graph save "Graph" "fig3b.gph", replace
twoway line cutpoint patients if trial==3, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(151, lpattern(dot)) xline(501, lpattern(shortdash_dot)) xlabel(201(300)1401)
graph save "Graph" "fig3c.gph", replace
twoway line cutpoint patients if trial==4, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(151, lpattern(dot)) xline(201, lpattern(shortdash_dot)) xlabel(201(300)1401)
graph save "Graph" "fig3d.gph", replace
twoway line cutpoint patients if trial==5, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(201, lpattern(dot)) xline(601, lpattern(shortdash_dot)) xlabel(201(300)1401)
graph save "Graph" "fig3e.gph", replace
twoway line cutpoint patients if trial==6, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(151, lpattern(dot)) xline(401, lpattern(shortdash_dot)) xlabel(201(300)1401)
graph save "Graph" "fig3f.gph", replace
twoway line cutpoint patients if trial==7, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(151, lpattern(dot)) xline(301, lpattern(shortdash_dot)) xlabel(201(300)1401)
graph save "Graph" "fig3g.gph", replace
twoway line cutpoint patients if trial==8, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(151, lpattern(dot)) xline(201, lpattern(shortdash_dot)) xlabel(201(300)1401)
graph save "Graph" "fig3h.gph", replace
twoway line cutpoint patients if trial==9, xticks(100(100)1300) ylabel(2.4(.2)3.6, angle(0)) yline(2.97 3.03, lpattern(dash)) xline(201, lpattern(dot)) xline(301, lpattern(shortdash_dot)) xlabel(201(300)1401)
graph save "Graph" "fig3i.gph", replace

/*************************/
/***** FIGURE 3 **********/
/*************************/
graph combine "fig3a.gph" "fig3b.gph" "fig3c.gph" "fig3d.gph" "fig3e.gph" "fig3f.gph" "fig3g.gph" "fig3h.gph" "fig3i.gph", row(3)
graph export "fig3.tif", as(tif) name("Graph") width(1200) replace
graph export "fig3.png", as(png) name("Graph") replace





/*************************************************************************/
/***** cutoffs for fixed sample sizes (base case that is scenario 1) *****/
/*************************************************************************/

/*** scenario 1 ***/
foreach i in 01 03 05 07{
  cutofffixedsamples 1 `i' 3
}

/*** scenario 2 ***/
foreach i in 01 03 05 07{
  cutofffixedsamples 2 `i' 3.18
}

/*** scenario 3 ***/
foreach i in 01 03 05 07{
  cutofffixedsamples 3 `i' 3.65
}

/*** scenario 4 ***/
foreach i in 01 03 05 07{
  cutofffixedsamples 4 `i' 3.88
}


/*********************************************************/
/***** algorithm-identified cutoffs, with steps n=50 *****/
/*********************************************************/

/*** scenario 1 ***/
foreach i in 01 03 05 07{
  optcutoff 1 `i' 3
}

/*** scenario 2 ***/
foreach i in 01 03 05 07{
  optcutoff 2 `i' 3.18
}

/*** scenario 3 ***/
foreach i in 01 03 05 07{
  optcutoff 3 `i' 3.65
}

/*** scenario 4 ***/
foreach i in 01 03 05 07{
  optcutoff 4 `i' 3.88
}


/**********************************************************/
/***** algorithm-identified cutoffs, with steps n=100 *****/
/**********************************************************/

/*** scenario 1 ***/
foreach i in 01 03 05 07{
  optcutoff2 1 `i' 3
}

/*** scenario 2 ***/
foreach i in 01 03 05 07{
  optcutoff2 2 `i' 3.18
}

/*** scenario 3 ***/
foreach i in 01 03 05 07{
  optcutoff2 3 `i' 3.65
}

/*** scenario 4 ***/
foreach i in 01 03 05 07{
  optcutoff2 4 `i' 3.88
}


/******************************************************/
/***** Supplemental Material S3 - Scenario 2 **********/
/******************************************************/
di 3.18*.99
di 3.18*1.01

use results_scen2_prev01.dta, clear 
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2.5(.5)5, angle(0)) yline(3.1482 3.2118)
graph save "Graph" "figS3_2a.gph", replace

use results_scen2_prev03.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2.5(.5)5, angle(0)) yline(3.1482 3.2118)
graph save "Graph" "figS3_2b.gph", replace

use results_scen2_prev05.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2.5(.5)5, angle(0)) yline(3.1482 3.2118)
graph save "Graph" "figS3_2c.gph", replace

use results_scen2_prev07.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2.5(.5)5, angle(0)) yline(3.1482 3.2118)
graph save "Graph" "figS3_2d.gph", replace


graph combine "figS3_2a.gph" "figS3_2b.gph" "figS3_2c.gph" "figS3_2d.gph", row(2)
graph save "Graph" "fig_S3_scen2.gph", replace
graph export "fig_S3_scen2.tif", as(tif) name("Graph") width(1200) replace
graph export "fig_S3_scen2.png", as(png) name("Graph") replace


/******************************************************/
/***** Supplemental Material S3 - Scenario 3 **********/
/******************************************************/
di 3.65*.99
di 3.65*1.01

use results_scen3_prev01.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2.75(.5)5.75, angle(0)) yline(3.6135 3.6865)
graph save "Graph" "figS3_3a.gph", replace

use results_scen3_prev03.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2.75(.5)5.75, angle(0)) yline(3.6135 3.6865)
graph save "Graph" "figS3_3b.gph", replace

use results_scen3_prev05.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2.75(.5)5.75, angle(0)) yline(3.6135 3.6865)
graph save "Graph" "figS3_3c.gph", replace

use results_scen3_prev07.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(2.75(.5)5.75, angle(0)) yline(3.6135 3.6865)
graph save "Graph" "figS3_3d.gph", replace


graph combine "figS3_3a.gph" "figS3_3b.gph" "figS3_3c.gph" "figS3_3d.gph", row(2)
graph save "Graph" "fig_S3_scen3.gph", replace
graph export "fig_S3_scen3.tif", as(tif) name("Graph") width(1200) replace
graph export "fig_S3_scen3.png", as(png) name("Graph") replace


/******************************************************/
/***** Supplemental Material S3 - Scenario 4 **********/
/******************************************************/
di 3.88*.99
di 3.88*1.01

use results_scen4_prev01.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(3(.5)8, angle(0)) yline(3.8412 3.9188)
graph save "Graph" "figS3_4a.gph", replace

use results_scen4_prev03.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(3(.5)8, angle(0)) yline(3.8412 3.9188)
graph save "Graph" "figS3_4b.gph", replace

use results_scen4_prev05.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(3(.5)8, angle(0)) yline(3.8412 3.9188)
graph save "Graph" "figS3_4c.gph", replace

use results_scen4_prev07.dta, clear
label var cutpoint "Cut-off point"
graph hbox cutpoint, over(patients) ylabel(3(.5)8, angle(0)) yline(3.8412 3.9188)
graph save "Graph" "figS3_4d.gph", replace


graph combine "figS3_4a.gph" "figS3_4b.gph" "figS3_4c.gph" "figS3_4d.gph", row(2)
graph save "Graph" "fig_S3_scen4.gph", replace
graph export "fig_S3_scen4.tif", as(tif) name("Graph") width(1200) replace
graph export "fig_S3_scen4.png", as(png) name("Graph") replace


/******************************/
/*** Appendix FIGURE A2 *******/ 
/**** real-life example *******/
/******************************/
use data_real_life_example.dta, clear
hist CAC, by(cvd) xlabel(0(2000)10000)
graph save "Graph" "Fig_A2_a.gph", replace

tab study gender, col
tab cvd gender, col

roctab cvd CAC, graph summary
graph save "Graph" "Fig_A2_b.gph", replace

graph combine "Fig_A2_a.gph" "Fig_A2_b.gph", col(1)
graph export "fig_A2.tif", as(tif) name("Graph") width(1200) replace

cutpt cvd CAC, nearest
*Empirical optimal cutpoint: 184.7;


/* evaluation of 17,251 participants with increments of n=50, starting with n=100 */
capture program drop _all

program define evaluation
tempname sim
postfile `sim' patients cutpoint using results.dta, replace
quietly {
  forvalues i = 101(50)17251 {
	cutpt cvd CAC if obsid<=`i', nearest
    scalar optco=e(cutpoint)
    post `sim' (`i') (optco) 
}
}
postclose `sim'
end

evaluation

*interval of 1% deviation from true optimal cut-off point;
di 184.7*.99
di 184.7*1.01


/******************************/
/*** FIGURE 4 *****************/ 
/******************************/
use results.dta, clear

twoway line cutpoint patients, yline(182.853 186.547, lpattern(shortdash)) ylabel(0(50)400, angle(0)) xlabel(0(1000)17000, angle(45)) ytitle("Cut-off point") xtitle(Patients) xline(351, lcolor(red) lpattern(dot)) xline(401, lcolor(red) lpattern(shortdash_dot))
graph export "fig_4.tif", as(tif) name("Graph") width(1200) replace

*When does the heuristic algorithm I, II stop due to less deviation than 1% from previous value?;
li in 1/20
*heuristic algorithm I: n=351;
*heuristic algorithm II: n=401;

*For which sample sizes does the chosen cut-off point fall within 1% deviation from the true value?;
gen targetrange = cond(cutpoint>=182.853 & cutpoint<=186.547, 1, 0)
tab targetrange
li patients cutpoint if targetrange==1

/*** end of file ***/